bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 33. Aventiure
___________________________________________________ #### Aventivre wie die bvrgonden #### mit den hevnen striten
###### 1951 | ### Also der chvene danchwart | vnder di tver getrat ### daz eceln gesinde | er hoher wichen bat ### mit blvte was bervnnen | allez sin gewant ### ein vil starchez waffen | daz trvg er bloz an siner hant
###### 1952 | ### vil lvt rief do danchwart | zv dem degene ### ir sitzet al ce lange | brvder hagene ### iv vnde got von himele | chlag ich vnser not ### ritter vnde knehte | sint in den herbergen tot
###### 1953 | ### er rief im hin engegene | wer hat daz getan ### daz het der herre blodelin | vnde sine man ### ovch hat ers ser engolten | daz wil ich iv sagen ### ich han mit minen handen | im sin hovbet abe geslagen
###### 1954 | ### daz ist ein schade chleine | sprach aber hagene ### da man saget maere | von einem degene ### ob er von rechen henden | verlivset sinen lip ### in svln deste ringer | chlagen waetlichiv wip
###### 1955 | ### nv saget mir brvder danchwart | wi sit ir so rot ### ich wene ir von vinden | lidet groze not ### ist er inder ime lande | derz iv hat getan ### in en nert der vbel tivfel | ez mvz im an sin leben gan
###### 1956 | ### dv sihest mich wol gesvnden | min wat ist blvtes naz ### von anderr manne wunden | ist mir geschehen daz ### der ich also manegen | hivte han erslagen ### ob ich es swern solde | ine chvndiz nimmer gesagen
###### 1957 | ### er sprach brvder danchwart | so hvetet vns der tver ### vnde lat der hivnen einen | chomen niht derfver ### ich wil reden mit den recken | als vns des twinget not ### vnser ingesinde | lit vor in vnverdienet tot
###### 1958 | ### sol ich sin chameraere | sprach der chvene man ### also richen chvenegen | ich gedienen chan ### so pflige ich der stiegen | nach den eren min ### den criemhilde degenen | chvnde leider niht gesin
###### 1959 | ### mich nimt des michel wunder | sprach aber hagene ### waz nv hinne rvnen | di hivnen degene ### si waen liht des enbaeren | der an der tvr da stat ### vnt div hovemaere | gesaget den bvergonden hat
###### 1960 | ### ich han vernomen lange | von criemhilde sagen ### daz si ir herceleide | wold niht vertragen ### nv trinchen wir di minne | vnde gelten skveneges win ### der ivnge vogt der hivnen | der mvz der erste sin
###### 1961 | ### do slvch daz chint ortlieben | hagen der helt gvt ### daz im gegen der hende | ame swerte vloz daz blvt ### vnt daz dem chvenege | daz hovbet spranch in di shoz ### do hvb sich vnder degenen | ein mort vil grimmech vnde groz
###### 1962 | ### darnach slvg er dem magtzogen | einen swinden slach ### mit beiden sinen henden | der des chindes pflach ### daz im daz hovbet schiere | vor dem thisse nider lach ### ez was ein iamerlichez lon | daz er dem magtzogen wach
###### 1963 | ### er sach vor eceln thisse | einen spilman ### hagen in sinem zorne | gahen dar began ### er slvch im vf der videlen | ab di zeswen hant ### daz habe dir ce botschepfte | in der bvrgonden lant
###### 1964 | ### so we mir miner hende | sprach werbel der spilman ### her hagen von tronege | waz het ich iv getan ### ich chom vf groze triwe | in iwerr herren lant ### wi chlinge ich nv di done | sit ich verlorn han di hant
###### 1965 | ### hagen geahtet ringe | gevidelte er nimmer mer ### do frvmt er in dem hvse | div mortgrimmen ser ### an den eceln rechen | der er so vil erslvch ### do braht er in dem hvse | livtes ce tode genvch
###### 1966 | ### volker der vil snelle | von dem thisse spranch ### sin videlboge im lvt | an siner hende erchlanch ### do videlte vngefvge | gvntheres spilman ### hey waz er im ce viende | der chvenen hivnen gewan
###### 1967 | ### ovch sprvngen von den thissen | di drie chvenege her ### si woldenz gerne scheiden | e daz shaden geshaehe mer ### si ne mohtenz mit ir sinnen | do niht vnderstan ### do volker vnde hagene | so sere wueten began
###### 1968 | ### do sach der vogt von rine | vngescheiden den strit ### do slvch der fvrste selbe | vil manige wunden wit ### dvrch di liehten ringe | den vianden sin ### er was ein helt cen handen | daz tet er groezliche schin
###### 1969 | ### do chom ovch zv dem strite | der starche gernot ### ia frvmte er der hivnen | vil manegen helt tot ### mit einem sharpfem swerte | daz gab im rvedeger ### den eceln rechen | tet er div groezlichen ser
###### 1970 | ### der ivnge svn vrovn vten | zv dem strite spranch ### sin waffen herlichen | dvrch di helm erchlanch ### den eceln recken | vzer hivnen lant ### da tet vil michel wunder | des chvenen giselheres hant
###### 1971 | ### swi frvm si alle waeren | di chvnege vnd alle ir man ### doch sach man vor in allen | giselheren stan ### gegen den vianden | er was ein helt gvt ### er frvmt da mit wunden | vil manegen vallen in daz plvt
###### 1972 | ### ovch werten sich vil sere | di eceln man ### do sach man di geste | hohwende stan ### mit den vil liehten swerten | dvrh des chveneges sal ### do horte man allenthalben | von wuffe grozen schal
###### 1973 | ### do wolden di darvz | zir frivnde sin darin ### di namen an den tvernen | vil chleinen gewin ### do waeren di darinne | vil gerne fver den sal ### danchwart liez ir deheinen | di stiegen vf vnde ovch ce tal
###### 1974 | ### des hvb sich vor dem tvrne | vil starcher gedranch ### vnde ovch von den swerten | grozer helmechlanch ### des chom der chvene danchwart | in eine groze not ### daz besorgete sin brvder | als im sin triwe daz gebot
###### 1975 | ### vil lvte rief do hagene | voelkeren an ### seht ir dort geselle | minen brvder stan ### vor hivnisschen recken | vnder starchen slegen ### vrivnt nert mir den brvder | e wir vliesen den degen
###### 1976 | ### daz tvn ich sicherlichen | sprach der spilman ### er begonde videlende | dvrch den palas gan ### ein hertez swert im ofte | an siner hende erchlanch ### di recken von dem rine | im sageten grozlichen danch
###### 1977 | ### volker der chvene | zv danchwarten sprach ### ir habt erlitten hivte | vil grozen vngemach ### mich bat iwer brvder | dvrch helfe zv ziv gan ### welt ir nv sin darvze | so wil ich innerthalben stan
###### 1978 | ### danchwart der snelle | stvnt vzerthalp der tver ### er werte in ir stiege | swaz ir chom darfver ### des horte man waffen hellen | den helden an der hant ### sam tet ovch innerthalben | volker von bvrgonden lant
###### 1979 | ### der chvene videlaere | rief veber di menege ### der sal ist wol beslozen | min vrint her hagene ### ia ist also verschranchet | div eceln tver ### von zweir helde handen | den gent wol tvsent rigel fver
###### 1980 | ### do von tronege hagene | di tver sah so behvt ### den schilt warf do ce rvke | der maere helt gvt ### do begond er erste rechen | daz im was getan ### do heten sine viande | cem lebene deheiner slahte wan
###### 1981 | ### do der vogt von rine | reht daz ersach ### daz hagen der starche | so manegen helm brach ### der chvenech der amelvnge | spranch vf eine banch ### er sprach hie shenchet hagene | daz allerwirsiste tranch
###### 1982 | ### der wirt het groze sorge | als im do daz gezam ### waz man im lieber vrivnde | vor sinen ovgen nam ### wande er vor sinen vinden | vil chvme da genas ### er saz vil angestlichen | was half in daz er kvenech was
###### 1983 | ### criemhilt div riche | rief dieterichen an ### nv hilf mir ritter edele | mit dem leben dan ### dvrch aller fversten tvgende | vzer amelvnge lant ### wand erreichet mich hagene | ich han den tot an der hant
###### 1984 | ### wi sol ich iv nv gehelffen | sprach her dieterich ### edeliv chvneginne | nv sorge ich vmbe mich ### ez sint so sere erzvernet | di gvntheres man ### daz ich an disen ziten | gefriden niemen chan
###### 1985 | ### neina herre dieterich | vil edel ritter gvt ### laza hivte schinen | den tvgentlichen mvt ### daz dv mir helfest hinnen | oder ich belibe tot ### der sorge gie criemhilde | vil harte groezliche not
###### 1986 | ### daz wil versvchen | ob ich iv gehelfen chan ### wande ich in manegen ziten | nie gesehen han ### so bitterlich erzvernet | so manegen ritter gvt ### ia sah er dvrch di helme | von swerten springen daz plvt
###### 1987 | ### mit krapf begonde rvfen | der degen vzerchorn ### daz sin stimme erlvte | alsam ein wisentes horn ### vnt daz div bvrch vil wite | von siner crapft erdoz ### div sterche dieteriches | was vnmaezliche groz
###### 1988 | ### do gehorte gventher | rvffen disen man ### in dem herten stvrme | losen er began ### er sprach dieteriches stimme | ist in min ore chomen ### ich waene im vnser degene | im haben etwaen hi benomen
###### 1989 | ### ich sih in vf dem thisse | er winchet mit der hant ### ir frivnt vnde mage | von bvergonden lant ### gehabt vf des strites | lat hoeren vnde sehen ### waz hi dem degene | von minen mannen si geschehen
###### 1990 | ### do der kvenech gventher | bat vnde ovch gebot ### si habten vf mit swerten | in des strites not ### daz was gewalt vil grozer | daz da niemen slvch ### ia vragete den von berne | der maere schiere genvch
###### 1991 | ### er sprach vil edel dieterich | waz ist iv hi getan ### von den minen vrivnden | willen ich des han ### bvze vnde svne der | bin ich iv bereit ### swaz iv iemen taete | daz waer mir innechlichen leit
###### 1992 | ### do sprach der herre dieterich | mir ist niht getan ### lat mich vz dem hvse | mit iwerem vride gan ### von disem herten strite | mit dem gesinde min ### daz wil ich sicherlichen | immer dienende sin
###### 1993 | ### wi vliehet ir so schiere | sprach do wolfrat ### ia hat der videlaere | di tver ni so verspart ### wir entsliezen so wite | daz wir dar fver gan ### nv swiget sprach her dieterich | ir habet den tivel getan
###### 1994 | ### do sprach der kvenech gventher | erlovben ich iv wil ### fvret vze dem hvse | lvecel oder vil ### ane mine vinde | di svln hi bestan ### si hant mir hi cen hivnen | so rehte leide getan
###### 1995 | ### do er daz gehorte | vnder arme er besloz ### di edeln kveneginne | der sorge div was groz ### do fvrt er anderthalben | eceln mit im dan ### ovch mit dieteriche | sehs hvndert waetlicher man
###### 1996 | ### do sprach der margrave | der edel rvedger ### sol aber vzem hvse | iemen chomen mer ### di iv doch gerne dienen | daz lazet vns vernemen ### so sol ovch vride staeter | den gvten vienden gezemen
###### 1997 | ### des antwurte giselher | von bvrgonden lant ### vride vnde svne | si iv von vns bechant ### sit ir sit triwen staete | ir vnde iwer man ### ir svlt vnangestlichen | mit iwern vrivnden hinnen gan
###### 1998 | ### do rvedeger der herre | gervmete den sal ### fvnfhvndert oder mere | im volgeten veber al ### der von baechelaren | vrivnt vnde siner man ### von dem chvenege rvedeger | schaden grozen sit gewan
###### 1999 | ### do sach ein hivnen recke | eceln gan ### bi dieteriche nahen | genozen wold er sin han ### dem gap der videlaere | einen solhen slach ### daz im vor eceln fvzzen | daz hovbet schiere gelach
###### 2000 | ### do der wirt des landes | chom fver daz hvs gegan ### do chert er sich hin widere | vnde sach volkeren an ### owe mir dirre geste | dice ist ein grimmigiv not ### daz alle mine recken | svln vor in wesen tot
###### 2001 | ### ach we der hohgezite | sprach der chvenech her ### da vihtet einer inne | der heizet voelker ### als ein eber wilde | vnde ist ein spilman ### ich danches minem heile | daz ich dem tivel entran
###### 2002 | ### sine leiche lvtent vbele | sine zvege di sint rot ### ia vellent sine doene | vil manigen helt tot ### ine weiz niht waz vns wize | der selbe spilman ### wand ich gast ni deheinen | so rehte leiden gewan
###### 2003 | ### si heten di si wolden | lazen fver den sal ### do hvb sich innerthalben | ein grozlicher schal ### di geste sere rachen | daz in e geschach ### volker der vil chvene | hey waz er helme cerbrach
###### 2004 | ### sich cherte gegen dem schalle | gventher der kvenech her ### hoert ir doene hagene | di dort volker ### videlt mit den hivnen | swer zv dem tvrn gat ### ez ist ein roter anstrich | den er ce dem videlbogen hat
###### 2005 | ### mich riwet ane maze | so sprach hagene ### daz ich ie gesaz in dem hvse | vor dem degene ### ich was sin geselle | vnde ovch er der min ### vnd chome wir immer wider heim | daz svln wir noch mit triwen sin
###### 2006 | ### nv schowe kvenech here | volker ist dir holt ### er dienet vlizechliche | din silber vnt din golt ### sin videlboge im snidet | dvrch den herten stal ### er brichet vf den helmen | div liehte schinenden mal
###### 2007 | ### ine gesach nie videlaere | so herlichen stan ### als der degen volker | hivte hat getan ### di sinen leiche hellent | dvrch helme vnd rant ### ia sol er riten gutiv ross | vnde tragen herlich gewant
###### 2008 | ### swaz der hivnen mage | in dem sal was genesen ### der en was nv deheiner | darinne me genesen ### des was der schal geswiftet | daz niemen mit in streit ### div swert von handen legeten | di chvenen recken gemeit

<<< Übersicht <<< vorige Seite nächste Seite >>>